@@ -16,25 +16,20 @@ def int_to_time(value: int, fps: float) -> time:
 
         return time(hour=int(h), minute=int(m), second=int(s), microsecond=int(ms))
     except ValueError:
-        raise InvalidTimestampError(value, '{int}', 'sub')
+        raise InvalidTimestampError(value, "{int}", "sub")
 
 
-def parse(
-        path: str,
-        encoding: str = "utf-8",
-        **kwargs
-) -> Iterator[Subtitle]:
-    fps = kwargs.get('fps', 23.976)
+def parse(path: str, encoding: str = "utf-8", **kwargs) -> Iterator[Subtitle]:
+    fps = kwargs.get("fps", 23.976)
 
     index = count(0)
 
     with open(path, encoding=encoding) as file:
-
         for line in file:
             line = line.rstrip()
 
-            start, end = line.replace('{', '').split('}')[:2]
-            lines = [t.split('}')[-1] for t in line.split('|')]
+            start, end = line.replace("{", "").split("}")[:2]
+            lines = [t.split("}")[-1] for t in line.split("|")]
 
             start = int_to_time(start, fps)
             end = int_to_time(end, fps)
